==> v_components-2.3.0.tar.gz: lib/widgets/button/grident_button.dart <==
// ignore_for_file: slash_for_doc_comments

/**
 * @author:   wzp_vicky
 * @time:     2023年9月14日08:01:58
 * @version:  V1.1
 * @description: 目前支持图片按钮(去掉了水波纹)和纯色按钮
 */

import 'package:flutter/material.dart';

class VGridentButton extends StatelessWidget {
  final Widget? child;
  final double? width;
  final double height;
  final Color? color;
  final Color? highlightColor;
  final Color? splashColor;
  final Gradient? gradient;
  final BorderRadius radius;
  final VoidCallback? onPressed;
  final BoxBorder border;
  final EdgeInsets padding;
  final EdgeInsets margin;

  const VGridentButton({
    Key? key,
    required this.child,
    this.width,
    this.height = 40.0,
    this.color,
    this.highlightColor,
    this.splashColor,
    this.gradient,
    this.radius = const BorderRadius.all(Radius.circular(6)),
    this.border = const Border.fromBorderSide(
      BorderSide(
        color: Color(0x00000000),
        width: 0,
        style: BorderStyle.solid,
      ),
    ),
    this.padding = const EdgeInsets.only(left: 6, right: 6),
    this.margin = const EdgeInsets.all(6),
    required this.onPressed,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
        margin: margin,
        width: width,
        height: height,
        decoration: BoxDecoration(
          color: color ?? Theme.of(context).colorScheme.secondary,
          gradient: gradient,
          borderRadius: radius,
          border: border,
        ),
        child: Material(
            color: Colors.transparent,
            child: InkWell(
                borderRadius: radius,
                highlightColor: highlightColor ?? Theme.of(context).highlightColor,
                splashColor: splashColor ?? Theme.of(context).splashColor,
                onTap: onPressed,
                child: Padding(
                  padding: padding,
                  child: Center(
                    child: child,
                  ),
                ))));
  }

  //TODO   需要改成跟MaterialButton
}

==> v_components-2.3.3.tar.gz: lib/widgets/button/grident_button.dart <==
// ignore_for_file: slash_for_doc_comments

/**
 * @author:   wzp_vicky
 * @time:     2023年9月14日08:01:58
 * @version:  V1.1
 * @description: 目前支持图片按钮(去掉了水波纹)和纯色按钮
 */

import 'package:flutter/material.dart';

class VButton extends StatelessWidget {
  final Widget? child;
  final double? width;
  final double height;
  final Color? color;
  final Color? highlightColor;
  final Color? splashColor;
  final Gradient? gradient;
  final BorderRadius radius;
  final VoidCallback? onPressed;
  final BoxBorder border;
  final EdgeInsets padding;
  final EdgeInsets margin;

  const VButton({
    Key? key,
    required this.child,
    this.width,
    this.height = 50.0,
    this.color,
    this.highlightColor,
    this.splashColor,
    this.gradient,
    this.radius = const BorderRadius.all(Radius.circular(6)),
    this.border = const Border.fromBorderSide(
      BorderSide(
        color: Color(0x00000000),
        width: 0,
        style: BorderStyle.solid,
      ),
    ),
    this.padding = const EdgeInsets.only(left: 6, right: 6),
    this.margin = const EdgeInsets.all(6),
    required this.onPressed,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
        margin: margin,
        width: width,
        height: height,
        decoration: BoxDecoration(
          color: color ?? Theme.of(context).colorScheme.secondary,
          gradient: gradient,
          borderRadius: radius,
          border: border,
        ),
        child: Material(
            color: Colors.transparent,
            child: InkWell(
                borderRadius: radius,
                highlightColor:
                    highlightColor ?? Theme.of(context).highlightColor,
                splashColor: splashColor ?? Theme.of(context).splashColor,
                onTap: onPressed,
                child: Padding(
                  padding: padding,
                  child: Center(
                    child: child,
                  ),
                ))));
  }

  //TODO   需要改成跟MaterialButton
}
